@@ -3,3 +3,8 @@ Python sensitivity analysis - run models with varying inputs to produce
 visualizations including gradient DataFrames and hex-bin plots
 """
 from sensitivity.main import SensitivityAnalyzer
+from sensitivity import _ignore_warn
+
+_ignore_warn.ignore_nested_library_warnings()
+
+
