@@ -41,7 +41,7 @@ def sensitivity_df(sensitivity_values: Dict[str, Any], func: Callable,
         param_dict.update(func_kwargs)
         result = func(**param_dict)
         base_param_dict.update({result_name: result})
-        df = df.append(pd.DataFrame(pd.Series(base_param_dict)).T)
+        df = pd.concat([df,pd.DataFrame(pd.Series(base_param_dict)).T])
     df.reset_index(drop=True, inplace=True)
     df = df.convert_dtypes()
     if labels:
@@ -66,7 +66,7 @@ def _two_variable_sensitivity_display_df(df: pd.DataFrame, col1: str, col2: str,
 
     # Fix for an odd Pandas bug introduced in 1.5
     # Even though this is effectively a no-op, without this was getting the following error
-    # once it would try to do .style.render() on the returned DataFrame
+    # once it would try to do .style.to_html() on the returned DataFrame
     # IndexError: Boolean index has wrong length: 1 instead of 2
     wide_df = wide_df.reset_index().set_index(col1)
 
